<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation>&lt;h5&gt; REV %1 &lt;/h5&gt;</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation>Controleren op updates</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>kon accountdatabase niet openen</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>Autorisatie verlopen, graag opnieuw aanmelden</translation>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation>Accountinstellingen</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Geef serveradres op</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 is geen geldig serveradres</translation>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation>Kon accountinformatie niet opslaan</translation>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation>Kon de wijzigingen niet opslaan: %1</translation>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation>Bijwerken huidige accountinformatie gelukt</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoogvenster</translation>
    </message>
    <message>
        <source>Server Address</source>
        <translation>Serveradres</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation>Kon bibliotheken van dit account niet desynchroniseren: %1</translation>
    </message>
    <message>
        <source>click to open the website</source>
        <translation>klik om de website te openen</translation>
    </message>
    <message>
        <source>pro version</source>
        <translation>pro-versie</translation>
    </message>
    <message>
        <source>No account</source>
        <translation>Geen account</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Kies</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation>Accountinstellingen</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Aanmelden</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Account toevoegen</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>niet aangemeld</translation>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation>Kon de lokale repository synchronisatie token: %1 niet verwijderen</translation>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation>Kon de synchronisatie informatie van server: %1 niet ophalen</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulier</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <source>email</source>
        <translation>e-mail</translation>
    </message>
    <message>
        <source>server</source>
        <translation>server</translation>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation>Bestandsactiviteit wordt uitsluitend ondersteund in %1 Server Professional editie.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>opnieuw</translation>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation>Ophalen van informatie activiteiten mislukt. %1 a.u.b.</translation>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation>Upload gelukt</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation>Bestand &quot;%1&quot;
succesvol geüpload.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation>Bestand &quot;%1&quot;
kon niet worden geüpload.</translation>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation>Kon de avatarsmap niet aanmaken</translation>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>Taken downloaden</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation>verwijder alle succesvolle taken</translation>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation>Op dit moment geen downloadtaken</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Opschonen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>Bibliotheek</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Pad</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>Deze taak annuleren</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>deze taak annuleren</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>Deze taak verwijderen</translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Kon deze taak niet annuleren:

%1</translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>Kon deze taak niet verwijderen:

%1</translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>Minimaliseren</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Bibliotheken</translation>
    </message>
    <message>
        <source>Starred</source>
        <translation>Favorieten</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation>Activiteiten</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>current download rate</source>
        <translation>huidige downloadsnelheid</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>huidige uploadsnelheid</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation>Kies een map om te synchroniseren</translation>
    </message>
    <message>
        <source>no server connected</source>
        <translation>geen server verbonden</translation>
    </message>
    <message>
        <source>all servers connected</source>
        <translation>alle servers verbonden</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>sommige servers niet verbonden</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulier</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>minimaliseren</translation>
    </message>
    <message>
        <source>close</source>
        <translation>sluiten</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selecteer</translation>
    </message>
    <message>
        <source>brand</source>
        <translation>brand</translation>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation>of sleep een map om te synchroniseren</translation>
    </message>
    <message>
        <source>download rate</source>
        <translation>downloadsnelheid</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation>pijlomlaag</translation>
    </message>
    <message>
        <source>upload rate</source>
        <translation>uploadsnelheid</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation>pijlomhoog</translation>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation>Fout bij het maken van de ccnet-configuratie</translation>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation>Kon de voorgeconfigureerde map &quot;%1&quot; niet aanmaken</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>kon %1 niet lezen</translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>Een bibliotheek aanmaken</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Kies een map</translation>
    </message>
    <message>
        <source>Creating...</source>
        <translation>Aanmaken...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation>Kon geen encryptiesleutel voor deze bibliotheek genereren</translation>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation>Kies een map om te synchroniseren</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>De map %1 bestaat niet</translation>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>Geef de naam op</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Geef het wachtwoord op</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>Wachtwoorden komen niet overeen</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Kon geen downloadtaak toevoegen:
%1</translation>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation>Kon geen bibliotheek op de server aanmaken:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Pad:</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Kies</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>gecodeerd</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>Wachtwoord opnieuw:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>statustekst</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>kon ccnet-configuratiemap niet laden %1</translation>
    </message>
    <message>
        <source>%1 client failed to initialize</source>
        <translation>Initialiseren van %1 client mislukt</translation>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>Geef het wachtwoord op</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>Synchroniseer bibliotheek &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation>Synchroniseer map &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation>Synchroniseer naar map:</translation>
    </message>
    <message>
        <source>or</source>
        <translation>of</translation>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation>synchroniseer met een bestaande map</translation>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation>een nieuwe synchronisatiemap aanmaken</translation>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation>Synchroniseer met deze bestaande map:</translation>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation>Kies een map</translation>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation>De map bestaat niet</translation>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation>Kies de map om te synchroniseren.</translation>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation>Je organisatie heeft de mogelijkheid een bibliotheek buiten de map %1 te plaatsen uitgeschakeld.</translation>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation>Conflicteert met bestaande bestand &quot;%1&quot;. Kies een andere map.</translation>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation>Conflicteert met bestaande bibliotheek &quot;%1&quot;. Kies een andere map.</translation>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation>De map &quot;%1&quot; bestaat reeds. Weet je zeker dat je hiermee wilt synchroniseren (inhoud zal worden samengevoegd)?</translation>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation>Kies nee om in plaats daarvan met een nieuwe map te synchroniseren</translation>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation>Kan geen alternatieve mapnaam vinden</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Kon geen downloadtaak toevoegen:
%1</translation>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation>Kon de repository download informatie: %1 niet ophalen</translation>
    </message>
    <message>
        <source>Download Library</source>
        <translation>Bibliotheek downloaden</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>kies...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>Wachtwoord voor deze bibliotheek:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation>Wijzigingendetails</translation>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation>Toegevoegde bestanden</translation>
    </message>
    <message>
        <source>Deleted files</source>
        <translation>Verwijderde bestanden</translation>
    </message>
    <message>
        <source>Modified files</source>
        <translation>Gewijzigde bestanden</translation>
    </message>
    <message>
        <source>Added folders</source>
        <translation>Toegevoegde mappen</translation>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation>Verwijderde mappen</translation>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Open</translation>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation>Bovenliggende map openen</translation>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation>Bestandsbeheer cloud</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vooruit</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Begin</translation>
    </message>
    <message>
        <source>Upload files</source>
        <translation>Bestanden uploaden</translation>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation>Een map uploaden</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation>Je hebt geen rechten op bestanden naar deze bibliotheek te uploaden</translation>
    </message>
    <message>
        <source>Create a folder</source>
        <translation>Een map aanmaken</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Vernieuwen</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder name</source>
        <translation>Mapnaam</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Ongeldige mapnaam!</translation>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation>De naam &quot;%1&quot; is al in gebruik.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>opnieuw</translation>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation>Kon geen bestandsinformatie ophalen&lt;br/&gt;%1</translation>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation>Geef de bestandsnaam op...</translation>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation>Kon het bestand &quot;%1&quot; niet verwijderen</translation>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation>Geef het pad naar de map waarheen je wilt opslaan op...</translation>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation>Wil je het bestaande bestand &quot;%1&quot; overschrijven?</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation>Bestand &quot;%1&quot; is niet gesynchroniseerd</translation>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation>Bestand %1 bestaat reeds.&lt;br/&gt;Wil je deze overschrijven?&lt;br/&gt;&lt;small&gt;(Kies nee om te uploaden met een alternatieve naam)&lt;/small&gt;</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation>Kon bestand niet downloaden: %1</translation>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation>Kies een te uploaden bestand</translation>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation>Kies een te uploaden map</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Hernoemen</translation>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation>Weet je zeker dat je deze items wilt verwijderen?</translation>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation>Aanmaken map mislukt</translation>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation>Bestandsvergrendeling mislukt</translation>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation>Kies een bestand om bij te werken %1</translation>
    </message>
    <message>
        <source>Rename failed</source>
        <translation>Hernoeming mislukt</translation>
    </message>
    <message>
        <source>Remove failed</source>
        <translation>Verwijderen mislukt</translation>
    </message>
    <message>
        <source>Share failed</source>
        <translation>Delen mislukt</translation>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation>Kan geen bestanden plakken vanuit dezelfde map</translation>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy failed</source>
        <translation>Kopiëren mislukt</translation>
    </message>
    <message>
        <source>Move failed</source>
        <translation>Verplaatsen mislukt</translation>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation>Aanmaken bibliotheek mislukt!</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation>Uploaden %1</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Downloaden %1</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 van %2</translation>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation>Bewerking geannuleerd</translation>
    </message>
    <message>
        <source>pending</source>
        <translation>in behandeling</translation>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Interne serverfout</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>De opslaglimiet is bereikt</translation>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation>vergrendeld door %1</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation>Laatst gewijzigd</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>Soort</translation>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation>Op&amp;slaan als...</translation>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation>&amp;Vergrendelen</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Hernoemen</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Verwijderen</translation>
    </message>
    <message>
        <source>Share to Group</source>
        <translation>Delen met groep</translation>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>&amp;Bijwerken</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiëren</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Knippen</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Plakken</translation>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation>Download &amp;annuleren</translation>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation>&amp;Synchroniseer deze map</translation>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation>Deze eigenschap is alleen beschikbaar in de pro-versie
</translation>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation>%1 downloadlink &amp;genereren</translation>
    </message>
    <message>
        <source>Share to User</source>
        <translation>Delen met gebruiker</translation>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation>Interne %1link g&amp;enereren</translation>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation>Op&amp;slaan als...</translation>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation>&amp;Ontgrendelen</translation>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation>Kon alleen-lezen bestanden niet verwijderen</translation>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation>Kon alleen-lezen bestanden niet knippen</translation>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation>Kon geen mappen aanmaken</translation>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation>Kon geen tijdelijke bestanden aanmaken</translation>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation>Kon bestand niet naar schijf wegschrijven</translation>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation>Kon oudere versie van het gedownloade bestand niet verwijderen</translation>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation>Kon bestand niet verplaatsen</translation>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>%1 initialisatie</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation>Kies %1-map</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Kies een map</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation>Initialisatie is niet afgerond. Wil je echt afsluiten?</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>De map %1 bestaat niet</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation>Kies een map</translation>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation>Kies een map. We zullen hierin een submap %1 aanmaken. Wanneer je een bibliotheek download zal deze hier standaard worden opgeslagen.</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Kies...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation>Controleren van je standaardbibliotheek...</translation>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation>Aanmaken van de standaardbibliotheek...</translation>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation>Kon geen standaardbibliotheek aanmaken:

Deze functie wordt alleen ondersteund in serverversie 2.1 of hoger.</translation>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation>Kon de standaardbibliotheek niet ophalen:
%1</translation>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation>Kon de standaardbibliotheek niet aanmaken:
%1</translation>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation>Standaardbibliotheek downloaden...</translation>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation>Kon standaardbibliotheek niet downloaden:
%1</translation>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation>De standaardbibliotheek is gedownload.
Je kunt op de knop &quot;Openen&quot; klikken om deze te bekijken.</translation>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation>Fout bij het downloaden van de standaardbibliotheek: %1</translation>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation>Kon standaardbibliotheek niet downloaden:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation>Overslaan</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Op de achtergrond uitvoeren</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Afronden</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>Standaardbibliotheek downloaden</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Een account toevoegen</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Opnieuw aanmelden</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Aanmelden...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Netwerkfout:
%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Waarschuwing:&lt;/b&gt; Het SSL-certificaat van deze server is niet vertrouwd. Toch doorgaan?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Geef serveradres op</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 is geen geldig serveradres</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Geef de gebruikersnaam op</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Geef de computernaam op</translation>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>Kon huidige account niet opslaan</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation>Tweeledige verificatiemethode </translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation>%1 serveradres</translation>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Geef het wachtwoord op</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation>Geef de tweeledige verificatiesleutel op</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>E-mailadres of wachtwoord onjuist</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Te kort na elkaar aangemeld. Een minuut wachten alstublieft</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Interne serverfout</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Kon niet aanmelden: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Kon niet aanmelden</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Bijvoorbeeld: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>of http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>statustekst</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Computernaam</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation>E-mailadres / Gebruikersnaam:</translation>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>bijv. Laptop van Jan</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Aanmelden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation>Je bent afgemeld.</translation>
    </message>
    <message>
        <source>login</source>
        <translation>aanmelden</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Een account toevoegen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>Vernieuwen</translation>
    </message>
</context>
<context>
    <name>MessageListener</name>
    <message>
        <source>failed to load ccnet config dir </source>
        <translation>kon ccnet-configuratiemap niet laden</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is unsynced. 
Reason: Deleted on server</source>
        <translation>&quot;%1&quot; is gedesynchroniseerd.
Reden: verwijderd van de server</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>&quot;%1&quot; is gesynchroniseerd</translation>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 conflict</source>
        <translation>Bestandsconflict %1</translation>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation>Kon het bestand %1 niet synchroniseren
Bestand is door een andere applicatie vergrendeld. Het bestand zal worden bijgewerkt wanneer je de applicatie afsluit.</translation>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation>Kon de map %1 niet synchroniseren
Een bestand in deze map is vergrendeld door een andere applicatie. Deze folder zal worden bijgewerkt wanneer je de applicatie afsluit. </translation>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other user on the server. Update to this file is not uploaded.</source>
        <translation>Kon het bestand %1 niet synchroniseren
Bestand is vergrendeld door een andere gebruiker op de server. Aanpassingen aan dit bestand worden niet geüpload.</translation>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation>Kon %1 niet synchroniseren
Bestandspad bevat ongeldige tekens. Het is niet gesynchroniseerd naar deze computer.</translation>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation>Kon het bestand %1 niet indexeren
Controleer de bestandsrechten en vrije schijfruimte.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync. 
Access denied to service</source>
        <translation>&quot;%1&quot; kon niet worden gesynchroniseerd.
Toegang tot dienst geweigerd</translation>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync.
The library owner&apos;s storage space is used up.</source>
        <translation>&quot;%1&quot; kon niet worden gesynchroniseerd.
De opslaglimiet van de eigenaar is bereikt.</translation>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation>Deel %1</translation>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation>Geef de groepsnaam op</translation>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation>Succesvol bijgewerkt</translation>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation>Actie om te delen mislukt: %1</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Succesvol verwijderd</translation>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation>Kon deelinformatie van de map niet ophalen</translation>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation>Kon je groeps- en contactinformatie niet ophalen</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Geef de gebruikersnaam op</translation>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation>Geef de groepsnaam op</translation>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation>Groep &quot;%1&quot; bestaat niet</translation>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation>Reeds gedeeld met groep %1</translation>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation>Reeds gedeeld met gebruiker %1</translation>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation>De vorige opdracht wordt nog uitgevoerd</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoogvenster</translation>
    </message>
    <message>
        <source>Share To:</source>
        <translation>Delen met:</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Delen</translation>
    </message>
    <message>
        <source>Permission:</source>
        <translation>Rechten:</translation>
    </message>
    <message>
        <source>Read-Write</source>
        <translation>Lezen en schrijven</translation>
    </message>
    <message>
        <source>Read-Only</source>
        <translation>Alleen lezen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation>gesynchroniseerd</translation>
    </message>
    <message>
        <source>indexing files</source>
        <translation>bestanden indexeren</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>synchronisatie initialiseren</translation>
    </message>
    <message>
        <source>downloading</source>
        <translation>downloaden</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>uploaden</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation>Synchronisatie samenvoegen</translation>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation>wachten op synchronisatie</translation>
    </message>
    <message>
        <source>server not connected</source>
        <translation>server niet verbonden</translation>
    </message>
    <message>
        <source>server authenticating</source>
        <translation>serverauthenticatie</translation>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation>automatische synchronisatie is uitgeschakeld</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>onbekend</translation>
    </message>
    <message>
        <source>Server has been removed</source>
        <translation>Server is verwijderd</translation>
    </message>
    <message>
        <source>You have not logged in to the server</source>
        <translation>Je bent niet op de server aangemeld</translation>
    </message>
    <message>
        <source>You do not have permission to access this library</source>
        <translation>Je hebt geen toegangsrechten tot deze bibliotheek</translation>
    </message>
    <message>
        <source>The storage space of the library owner has been used up</source>
        <translation>De opslaglimiet van de bibliotheekeigenaar is bereikt</translation>
    </message>
    <message>
        <source>Remote service is not available</source>
        <translation>Dienst op afstand is niet beschikbaar</translation>
    </message>
    <message>
        <source>Access denied to service</source>
        <translation>Toegang tot dienst geweigerd</translation>
    </message>
    <message>
        <source>Internal data corrupted</source>
        <translation>Interne data bechadigd</translation>
    </message>
    <message>
        <source>Failed to start upload</source>
        <translation>Kon upload niet starten</translation>
    </message>
    <message>
        <source>Error occured in upload</source>
        <translation>Fout opgetreden tijdens upload</translation>
    </message>
    <message>
        <source>Failed to start download</source>
        <translation>Kon download niet starten</translation>
    </message>
    <message>
        <source>Error occured in download</source>
        <translation>Fout opgetreden tijdens download</translation>
    </message>
    <message>
        <source>Library is damaged on server</source>
        <translation>Bibliotheek is beschadigd op de server</translation>
    </message>
    <message>
        <source>Conflict in merge</source>
        <translation>Conflict bij het samenvoegen</translation>
    </message>
    <message>
        <source>Server version is too old</source>
        <translation>Serverversie is te oud</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>Permission denied on server. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error</source>
        <translation>Netwerkfout</translation>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation>Kan geen verbinding maken met de server</translation>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation>Serverfout</translation>
    </message>
    <message>
        <source>Bad request</source>
        <translation>Ongeldig verzoek</translation>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation>Niet genoeg geheugen</translation>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation>Bibliotheek is op de server verwijderd</translation>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation>Bibliotheek is beschadigd op de server</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>De opslaglimiet is bereikt</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>Interne serverfout</translation>
    </message>
    <message>
        <source>Your %1 client is too old</source>
        <translation>Je applicatie %1 is te oud</translation>
    </message>
    <message>
        <source>Failed to sync this library</source>
        <translation>Kon deze bibliotheek niet synchroniseren</translation>
    </message>
    <message>
        <source>Files are locked by other application</source>
        <translation>Bestanden zijn door een andere applicatie vergrendeld</translation>
    </message>
    <message>
        <source>Library is deleted on server</source>
        <translation>Bibliotheek is op de server verwijderd</translation>
    </message>
    <message>
        <source>Error when accessing the local folder</source>
        <translation>Er is een fout opgetreden bij het aanroepen van de lokale map</translation>
    </message>
    <message>
        <source>initializing...</source>
        <translation>Initialiseren...</translation>
    </message>
    <message>
        <source>Failed to index local files</source>
        <translation>Kon lokale bestanden niet indexeren</translation>
    </message>
    <message>
        <source>Failed to check server information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create local files</source>
        <translation>Kon geen lokale bestanden aanmaken</translation>
    </message>
    <message>
        <source>Failed to merge local file changes</source>
        <translation>Kon geen lokale bestandswijzigingen samenvoegen</translation>
    </message>
    <message>
        <source>Incorrect password. Please download again</source>
        <translation>Wachtwoord onjuist. Download opnieuw</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation>Interne fout</translation>
    </message>
    <message>
        <source>connecting server...</source>
        <translation>verbinding maken met server...</translation>
    </message>
    <message>
        <source>indexing files...</source>
        <translation>bestanden indexeren...</translation>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation>Bestandslijst downloaden...</translation>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation>Bestanden downloaden...</translation>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>Map aanmaken...</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation>Bestandswijzigingen samenvoegen...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
    <message>
        <source>checking server info...</source>
        <translation>serverinfo controleren...</translation>
    </message>
    <message>
        <source>Canceling</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Canceled</source>
        <translation>Geannuleerd</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>SSL-fout</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Netwerkfout: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Serverfout</translation>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation>kon certificatendatabase niet openen</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation>Bestand &quot;%1&quot; bestaat niet in &quot;%2&quot;</translation>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation>%1 kon geen applicatie vonden op het bestand %2 te openen</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Bibliotheek &quot;%1&quot; aangemaakt</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Bibliotheek &quot;%1&quot; verwijderd</translation>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation>%1 hernoemen naar</translation>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation>Kon item &quot;%1&quot; niet downloaden</translation>
    </message>
    <message>
        <source>copy failed</source>
        <translation>kopie mislukt</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Toegevoegd</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Verwijderd</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Verwijderd</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Gewijzigd</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Hernoemd</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation>Toegevoegd of gewijzigd</translation>
    </message>
    <message>
        <source>Moved</source>
        <translation>Verplaatst</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Map toegevoegd</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Map verwijderd</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Map hernoemd</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Map verplaatst</translation>
    </message>
    <message>
        <source>files</source>
        <translation>bestanden</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>mappen</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>en nog %1 andere</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Bibliotheek teruggezet naar de status van</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>Bestand &quot;%1&quot; teruggezet naar de status van %2.</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Verwijderde map hersteld</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Naam of beschrijving van de bibliotheek gewijzigd</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation>Automatisch samenvoegen door het %1systeem</translation>
    </message>
    <message>
        <source>Just now</source>
        <translation>Zojuist</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>1 dag geleden</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>%1 dagen geleden</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 uur geleden</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 uur geleden</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>1 minuut geleden</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minuten geleden</translation>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation>&lt;Geen onderdeel van certificaat&gt;</translation>
    </message>
    <message>
        <source>Found another running process of %1, kill it and start a new one?</source>
        <translation>Er is een bestaand proces van %1 gevonden. Deze afsluiten en een nieuw proces starten?</translation>
    </message>
    <message>
        <source>Unable to start %1 due to the failure of shutting down the previous process</source>
        <translation>Kon %1 niet starten omdat het voorgaande proces niet afgesloten kon worden</translation>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation>Synchroniseer deze bibliotheek naar:</translation>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation>Synchroniseer deze map naar:</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Map</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>Alleen-lezen map</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Document</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>PDF-document</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>Afbeeldingsbestand</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>Tekstdocument</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>Audiobestand</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Videobestand</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Worddocument</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>PowerPoint-document</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Exceldocument</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation>Het pad &quot;%1&quot; conflicteert met het systeempad</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation>Het pad &quot;%1&quot; conflicteert met een bestaande bibliotheek</translation>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation>Pad is ongeldig</translation>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation>Fout bij indexeren</translation>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>Bibliotheek &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation>Deze bibliotheek is nog niet gedownload</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Fout:</translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation>elke %1 seconden</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation>Bibliotheeksymbool</translation>
    </message>
    <message>
        <source>RepoName</source>
        <translation>Bibliotheeknaam</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschrijving:</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>Tekstlabel</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Eigenaar:</translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>Laatst gewijzigd:</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation>mtime</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Grootte:</translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>Lokaal pad:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation>Bibliotheekstatus</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation>Synchronisatie-interval:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation>, %1%2</translation>
    </message>
    <message>
        <source>, %1</source>
        <translation>, %1</translation>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation>Deze bibliotheek is niet gedownload</translation>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation>Kon het bestand &quot;%1&quot; van de niet-bestaande bibliotheek &quot;%2&quot; niet openen</translation>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation>Onlangs bijgewerkt</translation>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>Mijn bibliotheken</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>Subbibliotheken</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation>Gedeeld met mij</translation>
    </message>
    <message>
        <source>Shared with all</source>
        <translation>Gedeeld met iedereen</translation>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation>Gedeeld met groepen</translation>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation>Gesynchroniseerde bibliotheken</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>Synchronisatie initialiseren</translation>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Automatische synchronisatie uitschakelen</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Automatische synchronisatie inschakelen</translation>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation>&amp;Details weergeven</translation>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation>Details van deze bibliotheek weergeven</translation>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation>&amp;Synchroniseer deze bibliotheek</translation>
    </message>
    <message>
        <source>Sync this library</source>
        <translation>Synchroniseer deze bibliotheek</translation>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation>Onlangs bijgewerkt</translation>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation>&amp;Nu synchroniseren</translation>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation>Synchroniseer deze bibliotheek meteen</translation>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>Download &amp;annuleren</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation>Download van deze bibliotheek annuleren</translation>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>Map &amp;openen</translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation>lokale map openen</translation>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation>Lokale map &amp;openen</translation>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation>&amp;Desynchroniseren</translation>
    </message>
    <message>
        <source>unsync this library</source>
        <translation>desynchroniseer deze bibliotheek</translation>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation>In cloud weergeven</translation>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation>Geef deze bibliotheek in de cloud weer</translation>
    </message>
    <message>
        <source>Share to user</source>
        <translation>Delen met gebruiker</translation>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation>Deel deze bibliotheek met een gebruiker</translation>
    </message>
    <message>
        <source>Share to group</source>
        <translation>Delen met groep</translation>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation>Deel deze bibliotheek met een groep</translation>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation>&amp;Open bestandsbeheer cloud</translation>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation>Open deze bibliotheek in de ingebouwde cloud-bestandsbeheerder</translation>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation>&amp;Hersynchroniseer deze bibliotheek</translation>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation>de- en hersynchroniseer deze bibliotheek</translation>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation>Synchronisatie-interval instellen</translation>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation>Kon de bibliotheek &quot;%1&quot; niet desynchroniseren</translation>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Kon deze taak niet annuleren:

%1</translation>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation>De download is geannuleerd</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation>Kon het bestand &quot;%1&quot; niet met zichzelf overschrijven</translation>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation>Kon het bestand &quot;%1&quot; niet verwijderen</translation>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation>Kon bestand niet uploaden: %1</translation>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation>Synchronisatie-interval (in seconden):</translation>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation>Synchronisatieinterval voor bibliotheek &quot;%1&quot; instellen</translation>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>opnieuw</translation>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation>Kon geen informatie over bibliotheken ophalen&lt;br/&gt;%1</translation>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Waarschuwing&lt;/b&gt; Het SSL-certificaat van deze server is niet vertrouwd. Toch doorgaan?</translation>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation>Kon standaardaccount niet toevoegen</translation>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation>Kon logbestand niet initialiseren: %s</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nee</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation>Interne %1-link</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiëren naar klembord</translation>
    </message>
    <message>
        <source>%1 Web Link:</source>
        <translation>%1 weblink:</translation>
    </message>
    <message>
        <source>%1 Protocol Link:</source>
        <translation>%1 protocollink:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>kon ccnet-configuratiemap %1 niet laden</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Automatische synchronisatie uitschakelen</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Automatische synchronisatie inschakelen</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation>Toon applicatiescherm</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation>&amp;Map %1 openen</translation>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation>Map %1 openen</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>Map &amp;logboeken openen</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Toon het scherm met informatie over de applicatie</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Online help</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation>automatische synchronisatie is uitgeschakeld</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation>Uploaden</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>map %1 logboeken openen</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>open %1 online hulp</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>sommige servers niet verbonden</translation>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation>In map &amp;tonen</translation>
    </message>
    <message>
        <source>Show in folder</source>
        <translation>In map tonen</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>opnieuw</translation>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation>Kon niet zoeken&lt;br/&gt;
%1</translation>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>Verbindingsstatus servers</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>verbonden</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>niet verbonden</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation>Geef het bibliotheekwachtwoord op</translation>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation>Geef het wachtwoord voor de bibliotheek %1 op</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Geef het wachtwoord op</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>Wachtwoord onjuist</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation>%1 automatisch opstarten na het aanmelden</translation>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation>%1-icoon verbergen</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP-proxy</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Socks5-proxy</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systeem proxy</translation>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation>Je hebt de taal gewijzigd. Herstarten op de wijziging door te voeren?</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation>Het proxy server adres kan niet leeg zijn</translation>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation>De proxy netwerkpoort is onjuist</translation>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation>De proxy gebruikersnaam mag niet leeg zijn</translation>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation>Het proxy wachtwoord mag niet leeg zijn</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation>Applicatiescherm verbergen na opstarten</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Melding wanneer bibliotheken zijn gesynchroniseerd</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Synchronisatie tijdelijke bestanden van MSOffice/Libreoffice inschakelen</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Snelheidslimiet download (KB/s):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Snelheidslimiet upload (KB/s)</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Basis</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation>Bibliotheek niet automatisch desynchroniseren</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation>Bibliotheek niet automatisch desynchroniseren wanneer de lokale map is verwijderd of niet toegankelijk is om andere redenen.</translation>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation>Niet desynchroniseren wanneer niet op de server gevonden</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation>Bibliotheek niet automatisch desynchroniseren wanneer deze niet op de server kan worden gevonden</translation>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation>FinderSync-extensie inschakelen</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>Verkenner-extensie inschakelen</translation>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation>Automatisch op updates controleren</translation>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>Het servercertificaat bij HTTPS-synchronisatie niet verifiëren</translation>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation>Synchroniseren met een bestaande map met een andere naam inschakelen</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Taal (herstart noodzakelijk)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Proxytype:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Poort:</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Gebruikersnaam:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>Proxyserver vereist een wachtwoord</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation>Lezen en schrijven</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation>Alleen lezen</translation>
    </message>
    <message>
        <source>Remove Share</source>
        <translation>Verwijder gedeelde onderdeel</translation>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation>Aangemaakt door %1</translation>
    </message>
    <message>
        <source>Read Write</source>
        <translation>Lezen en schrijven</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation>Alleen lezen</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Gebruiker</translation>
    </message>
    <message>
        <source>Permission</source>
        <translation>Rechten</translation>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation>De vorige opdracht wordt nog uitgevoerd</translation>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Deellink</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Deellink:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>Directe download</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiëren naar klembord</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Login with Shibboleth</source>
        <translation>Aanmelden met Shibboleth</translation>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>Kon huidige account niet opslaan</translation>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation>Niet-vertrouwde verbinding</translation>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation>%1 gebruikt een ongeldig beveiligingscertificaat. De verbinding kan onveilig zijn. Wil je toch doorgaan?</translation>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation>Huidige RSA-vingerafdruk is %1</translation>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation>Voorgaande RSA-vingerafdruk is %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Mijn keuze onthouden</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nee</translation>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Open</translation>
    </message>
    <message>
        <source>Open this file</source>
        <translation>Open dit bestand</translation>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation>op web weergeven</translation>
    </message>
    <message>
        <source>view this file on website</source>
        <translation>bekijk dit bestand op de website</translation>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation>opnieuw</translation>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation>Kon geen informatie over favorieten ophalen&lt;br/&gt;%1 a.u.b.</translation>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation>Je hebt nog geen favoriete bestanden.</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliotheek</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Pad</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tijd</translation>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Deïnstalleer %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Wil je de accountinformatie van %1 verwijderen?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Accountinformatie verwijderen...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>text</source>
        <translation>tekst</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nee</translation>
    </message>
</context>
</TS>